@@ -4,7 +4,7 @@ UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
 _magic_number = 6
-_modified_time = 1325895311.124668
+_modified_time = 1326343307.95461
 _template_filename='/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_p.mako'
 _template_uri='form_as_p.mako'
 _template_cache=cache.Cache(__name__, _modified_time)
@@ -21,8 +21,22 @@ def render_body(context,**pageargs):
         form = context.get('form', UNDEFINED)
         __M_writer = context.writer()
         # SOURCE LINE 1
-        for field in form:
+        if form._use_csrf_protection:
             # SOURCE LINE 2
+            __M_writer(u'<input type="hidden" name="csrf_token" value="')
+            __M_writer(unicode(form._csrf_token))
+            __M_writer(u'" />\n')
+            pass
+        # SOURCE LINE 4
+        if '_csrf' in form.errors:
+            # SOURCE LINE 5
+            __M_writer(u'<div class="errors">')
+            __M_writer(unicode(form.errors['_csrf'][0]))
+            __M_writer(u'</div><br />\n')
+            pass
+        # SOURCE LINE 7
+        for field in form:
+            # SOURCE LINE 8
 
             field_errors = ''
             if field.errors:
@@ -35,62 +49,73 @@ def render_body(context,**pageargs):
             
             __M_locals_builtin_stored = __M_locals_builtin()
             __M_locals.update(__M_dict_builtin([(__M_key, __M_locals_builtin_stored[__M_key]) for __M_key in ['field_errors','e'] if __M_key in __M_locals_builtin_stored]))
-            # SOURCE LINE 10
-            __M_writer(u'\n<p>\n')
-            # SOURCE LINE 12
-            if 'top' == labels_position:
-                # SOURCE LINE 13
-                __M_writer(unicode(field.label))
-                __M_writer(u'<br /> ')
-                pass
             # SOURCE LINE 16
+            __M_writer(u'\n<p>\n')
+            # SOURCE LINE 18
+            if 'top' == labels_position:
+                # SOURCE LINE 19
+                __M_writer(u'<label for="')
+                __M_writer(unicode(field.name))
+                __M_writer(u'">')
+                __M_writer(unicode(field.label))
+                __M_writer(u'</label><br /> ')
+                pass
+            # SOURCE LINE 22
             if field_errors and 'top'==errors_position:
-                # SOURCE LINE 17
+                # SOURCE LINE 23
                 __M_writer(unicode(field_errors))
                 __M_writer(u'<br /> ')
                 pass
-            # SOURCE LINE 20
+            # SOURCE LINE 26
             if 'left' == labels_position:
-                # SOURCE LINE 21
+                # SOURCE LINE 27
+                __M_writer(u'<label for="')
+                __M_writer(unicode(field.name))
+                __M_writer(u'">')
                 __M_writer(unicode(field.label))
-                __M_writer(u' ')
+                __M_writer(u'</label> ')
                 pass
-            # SOURCE LINE 24
+            # SOURCE LINE 30
             if field_errors and 'left'==errors_position:
-                # SOURCE LINE 25
+                # SOURCE LINE 31
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 28
+            # SOURCE LINE 34
             __M_writer(unicode(field))
             __M_writer(u' ')
-            # SOURCE LINE 29
+            # SOURCE LINE 35
             if 'bottom' == labels_position:
-                # SOURCE LINE 30
-                __M_writer(u'<br />')
+                # SOURCE LINE 36
+                __M_writer(u'<label for="')
+                __M_writer(unicode(field.name))
+                __M_writer(u'">')
                 __M_writer(unicode(field.label))
-                __M_writer(u' ')
+                __M_writer(u'</label> ')
                 pass
-            # SOURCE LINE 33
+            # SOURCE LINE 39
             if field_errors and 'bottom'==errors_position:
-                # SOURCE LINE 34
+                # SOURCE LINE 40
                 __M_writer(u'<br />')
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 37
+            # SOURCE LINE 43
             if 'right' == labels_position:
-                # SOURCE LINE 38
+                # SOURCE LINE 44
+                __M_writer(u'<label for="')
+                __M_writer(unicode(field.name))
+                __M_writer(u'">')
                 __M_writer(unicode(field.label))
-                __M_writer(u' ')
+                __M_writer(u'</label> ')
                 pass
-            # SOURCE LINE 41
+            # SOURCE LINE 47
             if field_errors and 'right'==errors_position:
-                # SOURCE LINE 42
+                # SOURCE LINE 48
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 44
+            # SOURCE LINE 50
             __M_writer(u'</p>\n')
             pass
         return ''
